[gnome-getting-started-docs] slower pacing for launching & intro



commit 2cceefd08f73c3a541d9cd02cb1ff01c11a486a5
Author: Jakub Steiner <jimmac gmail com>
Date:   Mon Nov 12 15:37:41 2012 +0100

    slower pacing for launching & intro

 animation/gnome-launching-applications.blend |  Bin 1685484 -> 1685484 bytes
 animation/gnome-launching-applications.py    |    6 +++---
 animation/gnome-yelp-intro.blend             |  Bin 1620228 -> 1620804 bytes
 animation/gnome-yelp-intro.py                |    6 +++---
 4 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/animation/gnome-launching-applications.blend b/animation/gnome-launching-applications.blend
index cc2ab05..df5764d 100644
Binary files a/animation/gnome-launching-applications.blend and b/animation/gnome-launching-applications.blend differ
diff --git a/animation/gnome-launching-applications.py b/animation/gnome-launching-applications.py
index 20b86e9..5de27df 100644
--- a/animation/gnome-launching-applications.py
+++ b/animation/gnome-launching-applications.py
@@ -4,9 +4,9 @@ from xml.etree import ElementTree as ET
 def typewriteit(scene):
   #FIXME make this happen only in scene "launching apps - keyboard"
   typewrite = bpy.data.objects['typewriter'].data.body
-  #psani zacina v sekvenci na 563
-  if bpy.context.scene.frame_current >= 563:
-    i = int((bpy.context.scene.frame_current-563)/3)
+  #psani zacina v sekvenci na 612
+  if bpy.context.scene.frame_current >= 612:
+    i = int((bpy.context.scene.frame_current-612)/3)
   else:
     i = 0
   #print(typewrite, i, typewrite[:i])
diff --git a/animation/gnome-yelp-intro.blend b/animation/gnome-yelp-intro.blend
index 4474080..3b3d40f 100644
Binary files a/animation/gnome-yelp-intro.blend and b/animation/gnome-yelp-intro.blend differ
diff --git a/animation/gnome-yelp-intro.py b/animation/gnome-yelp-intro.py
index 82c3594..5c5f7b8 100644
--- a/animation/gnome-yelp-intro.py
+++ b/animation/gnome-yelp-intro.py
@@ -25,9 +25,9 @@ def render(lang):
 def typewriteit(scene):
   #FIXME make this happen only in scene "launching apps - keyboard"
   typewrite = bpy.data.objects['typewriter'].data.body
-  #psani zacina v sekvenci na 369
-  if bpy.context.scene.frame_current >= 369:
-    i = int((bpy.context.scene.frame_current-369)/3)
+  #psani zacina v sekvenci na 527
+  if bpy.context.scene.frame_current >= 527:
+    i = int((bpy.context.scene.frame_current-527)/3)
   else:
     i = 0
   #print(typewrite, i, typewrite[:i])



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]